==> basic-information-sync-1.0-20220719.091626-32.jar: t_sync_person.sql <==
CREATE TABLE `t_sync_person` (
  `id` varchar(32) NOT NULL COMMENT '主键',
  `name` varchar(500) NOT NULL COMMENT '姓名',
  `password` varchar(500) NOT NULL COMMENT '密码',
  `name_brief_spell` varchar(100) DEFAULT NULL COMMENT '姓名拼音首字母,多音字使用逗号分隔',
  `sex` varchar(10) DEFAULT NULL COMMENT '性别',
  `code` varchar(100) NOT NULL COMMENT '账号',
  `identifier` varchar(18) DEFAULT NULL COMMENT '身份证号',
  `dep_id` varchar(32) DEFAULT NULL COMMENT '所属单位id',
  `dep_code` varchar(100) DEFAULT NULL COMMENT '所属单位编码',
  `position` varchar(100) DEFAULT NULL COMMENT '职级',
  `position_input` varchar(100) DEFAULT NULL COMMENT '职务',
  `office_phone` varchar(100) DEFAULT NULL COMMENT '办公电话',
  `note` varchar(500) DEFAULT NULL COMMENT '备注说明',
  `police` varchar(100) DEFAULT NULL COMMENT '警种',
  `smobile` varchar(100) DEFAULT NULL COMMENT '手机小号（暂时不用）',
  `order_Field` bigint(20) DEFAULT NULL COMMENT '排序号',
  `flag` int(1) DEFAULT '0' COMMENT '是否删除标志字段，0未删除；1删除。默认为0',
  `n_last_update_time` bigint(20) DEFAULT NULL COMMENT '更新时间',
  `tree_id` varchar(500) DEFAULT NULL COMMENT '单位id全排序（从根单位节点到当前单位节点），用-分隔',
  `tree_code` varchar(500) DEFAULT NULL COMMENT '单位code全排序（从根单位节点到当前单位节点），用-分隔',
  `PERSON_TYPE` varchar(32) DEFAULT NULL COMMENT '人员类型 详见码表code=PERSON_TYPE',
  `GRADE` varchar(32) DEFAULT NULL COMMENT '级别',
  `COMM_TYPE` varchar(32) DEFAULT NULL COMMENT '运营商编号，1移动，2联通 3电信(加固使用，暂时保留，一人一卡时录入页面提供)',
  `LEADER_LEVEL` varchar(64) DEFAULT NULL COMMENT '领导级别',
  `DISPLAY_STATE` varchar(32) DEFAULT NULL COMMENT '显示状态 ：  1显示 2不显示',
  `JOB` varchar(32) DEFAULT NULL COMMENT '岗位',
  `MOBILE_PERSONAL` varchar(500) DEFAULT NULL COMMENT '私人电话',
  `JX_FLAG` varchar(32) DEFAULT NULL COMMENT '警信用户 0不是，1是',
  `MOBILE_MULTIMEDIA_MESSAGE` varchar(500) DEFAULT NULL COMMENT '彩信电话',
  `personal_role` varchar(500) DEFAULT NULL COMMENT '人员角色1:管理员，2：开发者，3：使用者',
  `SERVICE_DEP_ID` varchar(500) DEFAULT NULL COMMENT '服务单位id',
  `MAIL` varchar(500) DEFAULT NULL COMMENT '邮箱',
  `company_info` varchar(500) DEFAULT NULL COMMENT '邮箱',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

==> basic-information-sync-1.0-20220720.071151-36.jar: t_sync_person.sql <==
CREATE TABLE `t_sync_person` (
  `id` varchar(32) NOT NULL COMMENT '主键',
  `name` varchar(500) NOT NULL COMMENT '姓名',
  `password` varchar(500) NOT NULL COMMENT '密码',
  `name_brief_spell` varchar(100) DEFAULT NULL COMMENT '姓名拼音首字母,多音字使用逗号分隔',
  `sex` varchar(10) DEFAULT NULL COMMENT '性别',
  `code` varchar(100) NOT NULL COMMENT '账号',
  `identifier` varchar(18) DEFAULT NULL COMMENT '身份证号',
  `dep_id` varchar(32) DEFAULT NULL COMMENT '所属单位id',
  `dep_code` varchar(100) DEFAULT NULL COMMENT '所属单位编码',
  `position` varchar(100) DEFAULT NULL COMMENT '职级',
  `position_input` varchar(100) DEFAULT NULL COMMENT '职务',
  `office_phone` varchar(100) DEFAULT NULL COMMENT '办公电话',
  `note` varchar(500) DEFAULT NULL COMMENT '备注说明',
  `police` varchar(100) DEFAULT NULL COMMENT '警种',
  `smobile` varchar(100) DEFAULT NULL COMMENT '手机小号（暂时不用）',
  `order_Field` bigint(20) DEFAULT NULL COMMENT '排序号',
  `flag` int(1) DEFAULT '0' COMMENT '是否删除标志字段，0未删除；1删除。默认为0',
  `n_last_update_time` bigint(20) DEFAULT NULL COMMENT '更新时间',
  `tree_id` varchar(500) DEFAULT NULL COMMENT '单位id全排序（从根单位节点到当前单位节点），用-分隔',
  `tree_code` varchar(500) DEFAULT NULL COMMENT '单位code全排序（从根单位节点到当前单位节点），用-分隔',
  `PERSON_TYPE` varchar(32) DEFAULT NULL COMMENT '人员类型 详见码表code=PERSON_TYPE',
  `GRADE` varchar(32) DEFAULT NULL COMMENT '级别',
  `COMM_TYPE` varchar(32) DEFAULT NULL COMMENT '运营商编号，1移动，2联通 3电信(加固使用，暂时保留，一人一卡时录入页面提供)',
  `LEADER_LEVEL` varchar(64) DEFAULT NULL COMMENT '领导级别',
  `DISPLAY_STATE` varchar(32) DEFAULT NULL COMMENT '显示状态 ：  1显示 2不显示',
  `JOB` varchar(32) DEFAULT NULL COMMENT '岗位',
  `MOBILE_PERSONAL` varchar(500) DEFAULT NULL COMMENT '私人电话',
  `JX_FLAG` varchar(32) DEFAULT NULL COMMENT '警信用户 0不是，1是',
  `MOBILE_MULTIMEDIA_MESSAGE` varchar(500) DEFAULT NULL COMMENT '彩信电话',
  `personal_role` varchar(10) DEFAULT NULL COMMENT '人员角色1:管理员，2：开发者，3：使用者',
  `mail` varchar(500) DEFAULT NULL COMMENT '邮箱',
  `SERVICE_unit_ID` varchar(500) DEFAULT NULL COMMENT '服务单位id',
  `vendors_Name` varchar(500) DEFAULT NULL COMMENT '厂商名称',
  `vendors_Telno` varchar(500) DEFAULT NULL COMMENT '厂商电话',
  `vendors_Address` varchar(500) DEFAULT NULL COMMENT '厂商地址',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
